### A Pluto.jl notebook ###
# v0.20.4

using Markdown
using InteractiveUtils

# This Pluto notebook uses @bind for interactivity. When running this notebook outside of Pluto, the following 'mock version' of @bind gives bound variables a default value (instead of an error).
macro bind(def, element)
    #! format: off
    quote
        local iv = try Base.loaded_modules[Base.PkgId(Base.UUID("6e696c72-6542-2067-7265-42206c756150"), "AbstractPlutoDingetjes")].Bonds.initial_value catch; b -> missing; end
        local el = $(esc(element))
        global $(esc(def)) = Core.applicable(Base.get, el) ? Base.get(el) : iv(el)
        el
    end
    #! format: on
end

# ╔═╡ feb39810-13bf-4383-8184-9338111248cf
using HypertextLiteral, PlutoUI, PlutoPlotly, CSV, Dates, DataFrames

# ╔═╡ f9dd4fc1-c759-4d80-b560-4ede0a84f6e9
html"""
<picture>
  <source srcset="https://gci.iscte-iul.pt/2022/identidade/files/brand_v2/escolas/rgb/ibs/en/horizontal/negative/rgb_ibs_en_horizontal_negative.png" media="(prefers-color-scheme: dark)" width="240px!important" style="float:right;">
  <img src="https://gci.iscte-iul.pt/2022/identidade/files/brand_v2/escolas/rgb/ibs/en/horizontal/main/rgb_ibs_en_horizontal_main.png" width="240px" style="float:right;">
</picture>
"""

# ╔═╡ 15112ba0-cddf-11eb-07a3-2bcd9257c8d0
md"""
# Week 5 - Monetary Policy & Aggregate Demand
## Exercises

**Macroeconomics, ISCTE-IUL**

"""

# ╔═╡ 3cdf6437-0705-410c-8b0b-e8fc657897ed
md"""
**Vivaldo Mendes, Ricardo Gouveia-Mendes, Luís Clemente-Casinhas** 

**March 2025**
"""

# ╔═╡ 49a435e3-e710-4d01-84f5-396b151316e3
md"""
---
"""

# ╔═╡ 409f9114-3fe1-4abe-8beb-ab279e9031b2
md"""
### Packages used in this notebook
"""

# ╔═╡ ced63ea2-60c8-4913-a5d4-9e1b5ff47223
md"""
---
"""

# ╔═╡ 6571612f-00ad-4179-bb93-a48cc9804352
md"""
## Exercise 1. The Monetary Policy curve
"""

# ╔═╡ dac7fb80-10f7-4806-af0c-088637b79b69
md"""

Assume the monetary policy curve is given by: 

$$r=\overline{r}+\lambda \pi$$
with: $\overline{r}=1.5,\lambda =0.75$. Answer the following questions.

👉 **(a)** The MP curve reflects the behavior of what institution in a developed market economy?

"""

# ╔═╡ 164f08a1-63b2-42e5-9811-a0431b7a667c
md"""
!!! answer "Answer (a)"

	The MP curve reflects the behavior of the central bank in a developed market economy. It tells what macroeconomic variables this bank takes into account when setting interest rates.

"""

# ╔═╡ dd38b7eb-925e-4691-8b51-b77acce6c48c
md"""
👉 **(b)** In the MP curve above, which variables are endogenous? And exogenous? What is λ?

"""

# ╔═╡ 370b96a7-a5dd-45c4-a46f-1d13a4f87663
md"""
!!! answer "Answer (b)"

	The variables $\pi$ and $r$ are endogenous because their values depend on the functioning of the entire economy. $\overline{r}$ is an exogenous variable because it does not directly depend on the functioning of the economy: it is determined by some exogenous force, like a Covid19 shock, a war, or some shock that affects the marginal productivity of capital. $\lambda$ is a parameter that tells how much the central bank dislikes inflation. 

"""

# ╔═╡ 96d63fec-da09-4c16-8019-10a6b63d3f73
md"""
👉 **(c)** Calculate the real interest rate when the inflation rate is 0%, 2%, and 4%.

"""

# ╔═╡ 4471e3b1-fa13-4ae7-a78b-458e4d685933
md"""
!!! note

	To solve the numerical parts of this exercise, we must first insert the values of $\bar{r}$ and $\lambda$ into the notebook. We do this in the cell below.

	We can answer (c) using a traditional calculator because the operations are elementary. However, it is inefficient because we must repeat the operations three times. It will be much easier and faster to use a simple function inside the notebook, as we illustrate next:

"""

# ╔═╡ f1acdec8-d55b-4b12-9b67-84c47be9378e
begin
	r̄ = 1.5 ;	λ = 0.75 ; 			# inserting the values of r̄ and λ
	r(π) = r̄ .+ λ .* π 				# The MP function (it looks like a mathematical function)
	π = [0 , 2 , 4] 				# Attributing values to π (the domain of the function)
	r(π) 							# Give me the output 
end

# ╔═╡ 3f23006c-9918-4883-a1c2-f982862f2cf3
md"""
👉 **(d)** The figure "MP Curve" below plots the monetary policy curve. What do the three dots tell us?
"""

# ╔═╡ ce89db42-eabe-4d30-8d0a-4b06ad04145a
md"""
!!! answer "Answer (c)"

	For an inflation rate at 0%, 2%, and 4%, the real interest rate will be equal to 1.5%, 3%, and 4.5%, respectively.

"""

# ╔═╡ d38d5d7e-ef45-40e7-90c0-441fa4d30a24
begin
	r1 = 0.0:0.01:6.0
	
	π1 = - (r̄ ./ λ) .+  r1 ./ λ 
	
	trace5_0 = scatter(; x = r1, y = π1, mode="lines" , line_color = "Brown", line_width = "3",
					name  = "MP")
	
	trace5_1 = scatter(; x = [1.5, 3.0, 4.5], y = [0.0, 2.0, 4.0], text =["1", "2" , "3"], 
					textposition = "top center", name ="Eq.", mode="markers+text", marker_size= "12",
					marker_color="Brown", textfont = attr(family="sans serif", size=16, color="black"))
	
	layout5_1 = Layout(;
					height = 450,
					title_text ="MP curve", 
					title_x = 0.5,
					hovermode ="x",
                    xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
                    xaxis_range = [-0.1, 6.0],
					yaxis_range = [-2.0, 6.0],
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false))

   p5_1 = plot([trace5_0, trace5_1], layout5_1)
end

# ╔═╡ 0120645b-0386-4fdd-b7fd-ace3f58c2d4d
md"""
!!! answer "Answer (d)"

	They tell us the central bank's reaction to the three different inflation rates. If inflation increases, the central bank will increase real interest rates. By how much? It depends on how much the central bank dislikes inflation. The more the central bank dislikes inflation, the higher will be $\lambda$, and the higher the slope of the MP curve.

"""

# ╔═╡ f1a259ac-e3c3-457a-9111-5eab394f452f
md"""
---
"""

# ╔═╡ 1b35a949-7c83-4d64-aa69-90b42c5dfbfb
md"""
## Exercise 2. A shift in the Monetary Policy curve
"""

# ╔═╡ 5235a517-8947-4d57-a436-c48eb3de87c6
md"""
Refer to the monetary policy curve described in Problem 1. Assume now that the monetary policy curve is given by $r = 2.5 + 0.75 \pi$.

👉   **(a)** In the current exercise, does the central bank dislike inflation more or less than in the previous exercise?

👉   **(b)** Using the slider below, plot the new monetary policy curve on the graph created in Problem 1.

👉   **(c)** Does the new monetary policy curve represent an autonomous tightening or loosening of monetary policy?

"""

# ╔═╡ aa6e1a71-1cc4-4ddc-b080-11de86462656
md"""
!!! answer "Answer (a)"

	As the value of $\lambda$ is the same in both exercises $(\lambda=0.75)$, the central bank's reaction to inflation is the same.

"""

# ╔═╡ 6bf1aae8-5d3a-4aa2-b01c-d633602f3c55
md"""
`r̄2 = ` $(@bind r̄2 Slider(0.0:0.5:3.0, default=1.5, show_value=true))     
"""

# ╔═╡ 0fd242c3-a99f-41b3-a5ed-1c92f6d3b600
begin	
	π2_Δr̄2 = - (r̄2 ./  λ) .+  r1 ./ λ 
			
	trace5_2 = scatter(; x = r1, y = π2_Δr̄2, mode="lines" , line_color = "Purple", line_width = "3",
					 name  = "MP2")
	
	trace5_3 = scatter(; x = [1.5, 3.0, 4.5], y = [-4/3, 2/3, 8/3], text =["1''", "2''" , "3'"], 
					 textposition = "top center", name ="Eq.", mode="markers+text", 
					 marker_size= "12", marker_color="Purple", 
					 textfont = attr(family="sans serif", size=16, color="black"))
	
	trace5_4 = scatter(; x = [2.5, 4.0, 5.5], y = [0.0, 2.0, 4.0], text =["1'", "2'" , "3'"], 
					 textposition = "top center", name ="Eq.", mode="markers+text", 
					 marker_size= "12", marker_color="Purple", 
					 textfont = attr(family="sans serif", size=16, color="black"))
	
	layout5_4 = Layout(;
					height = 450,
					title_text ="MP curve", 
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
                    xaxis_range = [-0.1, 6.0],
					yaxis_range = [-2.0, 6.0],
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false))

	p5_4 = plot([trace5_2, trace5_4, trace5_0, trace5_1], layout5_4)
end

# ╔═╡ 4c2622b9-191f-4e38-b5f4-c0eece8cb7af
md"""
!!! answer "Answer (b)"

	By setting the slider to $\bar{r}2=2.5$, the MP curve will shift to the right (see figure above). For any level of inflation, the real interest rate will be higher by 1 pp.
"""

# ╔═╡ 559be550-e0b0-4cd4-bd16-f7757bb190cb
md"""
!!! answer "Answer (c)"

	For any level of inflation, the real interest rate is higher than before, which means that the central bank is tightening its monetary policy.

	We say that we have a tightening monetary policy because the central bank increases the real interest rate to force the level of aggregate demand to go down $(\downarrow D)$, which will bring GDP down $(\downarrow Y)$, and consequently leading to a reduction in inflation.

"""

# ╔═╡ 39562a1b-7a97-4ccd-b57c-9fb4bb15ba65
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 85981e5d-1519-4dca-8739-4023e58a0176
md"""
## Exercise 3. A comprehensive exercise
"""

# ╔═╡ 7d5db723-241f-4504-b7d7-8c1e50a3b5a8
md"""
The following information is known about the aggregate demand and the central bank's behavior:
- Autonomous aggregate demand: $\overline{A} = 7.6$
- The multiplier: $m= 2.0$
- The impact of $r$ upon aggregate demand: $\phi=0.2$
- The MP curve is given by: 

$$r=\overline{r}+\lambda \pi$$
with $\overline{r}=2\%$ and $\lambda = 0.5$. Take into account that the value $2\%$ is expressed in percentage points, so that $2\%$ is just $2$. Answer the questions below, but firstly, let us insert the values of the parameters and exogenous variables into the notebook:

"""

# ╔═╡ 2995b122-9938-4027-8c1f-89967ddf5f75
Ā3 = 7.6 ;	λ3 = 0.5 ;	m3 = 2.0 ;	ϕ3 = 0.2 ;	r̄3 = 2.0 ;

# ╔═╡ 72b279a0-9405-4a39-b715-4a7352cc5b45
md"""
👉   **(a)** In the MP curve above, which macroeconomic variables are endogenous? And exogenous? What is λ?

"""

# ╔═╡ 022623ff-7979-4690-9c1a-0c8977c1d976
md"""
!!! answer "Answer (a)"

	The variables $\pi$ and $r$ are endogenous because their values depend on the functioning of the entire economy. $\overline{r}$ is an exogenous variable because it does not directly depend on the functioning of the economy: it is determined by some exogenous force, like a Covid19 shock, a war, or some shock that affects the marginal productivity of capital. $\lambda$ is a parameter that tells how much the central bank dislikes inflation. 

"""

# ╔═╡ 0c8a41dd-b6c6-47ed-b4dc-2c81b6638044
md"""
👉   **(b)** Obtain the expression of the AD curve.
"""

# ╔═╡ 3556cde6-e9b0-4dab-a8ae-dbc24f524b22
md"""
!!! hint

	Recall the IS curve:

	$$\tag{IS} Y=m \cdot \overline{A}-m \cdot \phi \cdot r$$

	Recall the MP curve: 

	$$\tag{MP} r=\overline{r}+\lambda \pi$$

	The AD curve is obtained by inserting the MP curve into the IS curve.

"""

# ╔═╡ ebb43969-4b22-4e8e-8694-6b47a8726b86
md"""
!!! answer "Answer (b)"

	Inserting the values of parameters and $\overline{A}$ into the IS curve and using the MP curve $(r = 2 + 0.5 \pi)$, we get:
	
	$$Y= 2.0 \times 7.6 - 2.0 \times 0.2 \times (2.0+0.5 \times \pi)$$
	$$\tag{AD} Y= 2.0 \times 7.6 - 0.8 - 0.2 \times \pi$$

"""

# ╔═╡ b20800ee-7d04-4e15-9aa0-d86aca961461
md"""
👉   **(c)** The MP and the AD curves are represented graphically below. If inflation is $2\%$, what is the level of aggregate demand and the real interest rate set by the central bank?

"""

# ╔═╡ 280f3cc5-0a2b-4cd3-bcfb-cba536877019
md"""
!!! answer "Answer (c)"

	Notice that using Pluto allows us to get the answer without having to do any numerical calculations. Using the mouse on top of the curves, we can easily see that if $\pi = 2\%$, then $r=3\%$, and Y = \$14 trillion.

"""

# ╔═╡ 91a1906c-f969-4265-911c-2dfab3bf35bf
md"""

👉   **(d)** The figure below presents two points: 1 and 2. How do you explain the movement from points 1 to 2?
"""

# ╔═╡ 5bbebe42-69cd-474a-ad1a-8599fed108be
md"""
!!! answer "Answer (d)"

	If inflation increases from $\pi = 2\%$ to $\pi = 4\%$, then the central bank increases the real interest rate from $r=3\%$ to $r=4\%$, and aggregate demand will decline from  Y= \$14  trillion to Y = \$13.6 trillion.

	"""

# ╔═╡ 4cd62077-945d-4b33-af50-739612c29410
md"""

👉   **(e)** What is the value of the nominal interest rate at both points above? Is the Taylor principle satisfied in this exercise?

"""

# ╔═╡ fd292c9b-ed3e-4f91-aea6-4142e429163a
md"""
!!! answer "Answer (e)"

	The value of the nominal interest rate in both situations is obtained by using the Fisher equation:

	$$i =\pi + r$$

	Therefore:

	- If $r=3\%$ and $\pi = 2\%$, then $i= 5\%$.

	- If $r=4\%$ and $\pi = 4\%$, then $i= 8\%$.

	The Taylor principle is satisfied in this exercise because

	$$\Delta i>\Delta \pi$$
	$$3\% >2\%.$$

"""

# ╔═╡ 5c2e6ae3-cfda-4653-8e47-b6dc018129b5
md"""
👉   **(f)** Consider the central bank is losing control of the inflationary pressures in the economy. It takes a drastic measure by increasing $\overline{r}%$ to $3\%$. What happens to the MP and AD curves? Using the slider `Δr̄3` below, represent graphically.
"""

# ╔═╡ 1fb6c731-ff80-41fd-b866-0db9ad4ec361
md"""
`Δr̄3 = ` $(@bind Δr̄3 Slider(-2.0:0.25:2.0, default=0.0, show_value=true))     
"""

# ╔═╡ 5fe68e9d-3ff2-495e-b844-649e273ce758
md"""
!!! answer "Answer (f)"

	 This question involves a **shift** of the MP curve from points 1 to 1', or from 2 to 2'. This type of movement is entirely different from a movement along this curve as we had in question (d). Now, for the same inflation level, we have a higher level of the real interest rate and a lower level of aggregate demand.

"""

# ╔═╡ 0f86d6fa-bdd4-4018-b3af-39e0bb1288f7
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 113c8a60-335b-4b3b-bffa-9e7e9de7aa1b
md"""
## Exercise 4. The MP curve and the Fisher equation
"""

# ╔═╡ b22cdf3b-4806-4ab9-8b4a-a4112bb9de26
md"""

To get a better understanding of what the MP curve stands for, it is convenient to combine it with the Fisher equation. From week 2, we recall that the Fisher equation is given by:

$$i=r+\pi \tag{1}$$

where $i$ stands for the **_nominal_** interest rate, $\pi$ for the inflation rate, and $r$ as the **_real_** interest rate. And in this week, we learned that the MP curve is given by:

$$r=\overline{r}+ \lambda \pi \tag{2}$$

By inserting eq. (2) into (1), we get:

$$i = \overline{r}+(1+\lambda)\pi \tag{3}$$

Now, we can arrive at an exciting point. Because the central bank **_by law_** has the power to set $i$ directly, eq. (3) shows the variables that explain why this bank changes $i$. According to the MP curve and the result in eq. (3) the central bank changes $i$:
- if $\overline{r}$ changes
- if $\pi$ changes
- if $\lambda$ changes 

The figure below plots the Fed's decisions concerning the **_nominal_** interest rate $(i)$ and the inflation rate $(\pi)$ for the US economy between 2009 and 2022. In the US, the nominal interest rate $(i)$ is known as the "Federal Funds Rate", and the shaded area is the range the Fed will allow that rate to fluctuate.
"""

# ╔═╡ b91fc2c4-afa9-4ed5-bf33-67ac2aadd7b6
md"""
👉 **(a)** In the figure above, we can observe three different types of decisions by the Fed that can be explained by the MP curve: keep the range unchanged, gradually change the range, and aggressively change the range. Can you give examples of periods where that occurred?
"""

# ╔═╡ 8596ced0-f0fa-46b4-be9a-30a16798f203
md"""
!!! answer "Answer (a)"

	1. Keep the range unchanged: from January 2009 up to December 2015
	2. Change the range gradually: from January 2016 up to December 2018 and from July 2019 to February 2020
	3. Radically change the range: from February 2020 to April 2020.
"""

# ╔═╡ ac06af9d-9cf5-4229-9cd3-dfdb2492c18e
md"""
👉 **(b)** According to the MP curve, what facts may explain that from January 2009 up to December 2015, the Fed decided to keep the interest rate range unaltered?
"""

# ╔═╡ 113036a0-df28-4c86-aad8-df89b4b3129f
md"""
!!! answer "Answer (b)"

	The Fed did not change the interest rate range because it considered that there was no **_significant_** change in the variables in the MP curve in that period:

	1. Interest rates were at the zero lower bound: reducing them below zero is an abnormal economic and financial decision.
	2. There were no inflationary pressures in the economy: the inflation rate $(\pi)$ was coming down to 0% (or even negative values).
	3. The economy was coming out from the most severe recession since the 1930s, and the natural interest rate $(\overline{r})$ was close to 0%.
	4. The Fed did not change its "aversion" to inflation (therefore, $\lambda$ remained constant).


	Therefore, there were no reasons for the Fed to raise interest rates or to reduce them below zero.
	
	"""

# ╔═╡ 8c1fa8b9-f490-4ac5-83cb-75317a6d1f37
md"""
👉 **(c)** According to the MP curve, what facts may explain that between 2016 and 2019, the Fed decided to gradually increase the interest rate range step-by-step?
"""

# ╔═╡ 92296571-e28b-4fbc-9529-551a80e3aefc
md"""
!!! answer "Answer (c)"

	Because the Fed considered inflation to be increasing gradually during such a period: in September 2015, the inflation rate was 0%, but in January 2017, it reached 2.8% in just 14 months. The Fed saw inflation going up month-by-month on a sustainable path, reaching values higher than 2% (the desired level of inflation for the Fed), and decided that the time had arrived for similarly raising interest rates: gradually, step-by-step.
	
"""

# ╔═╡ facf71b4-61fc-42eb-8cbc-44f120a5fb94
md"""
👉 **(d)** According to the MP curve, what facts may explain why, between February 2020 and March 2020, the Fed decided to slash the interest rate range down to zero percent in such a remarkably short period?
"""

# ╔═╡ eff0090d-8174-4f9f-a454-b8377b6f331c
md"""
!!! answer "Answer (d)"

	The COVID-19 pandemic provoked a collapse of the natural real interest rate $(\overline{r})$, as most firms were forced to halt production, and most workers were forced to remain at home in quarantine. Under these circumstances, the Fed tried to fight the negative impact of that collapse by reducing nominal interest rates $(i)$ to zero percent.
	
"""

# ╔═╡ b8685f1b-5f5f-4f9f-9b98-32521ca26d24
md"""
---
"""

# ╔═╡ 96c81523-b9b1-46a5-9880-a4152e097a58
md"""
## Exercise 5. Interest rates & the ECB
"""

# ╔═╡ 6cdba781-6a44-496f-869a-f6c83208b49b
md"""
Below, we can find an extract of the speech by Christine Lagarde (the President of the European Central Bank: ECB), delivered at a Press Conference on 2 February 2023 [(link here)](https://www.ecb.europa.eu/press/pr/date/2023/html/ecb.mp230202~08a972ac76.en.html), where she announced the decisions made by the Board regarding big increases in short term interest rates.

"""

# ╔═╡ a5de4a7b-5768-49d7-b273-97b929f38d95
md"""
>“The Governing Council will stay the course in raising interest rates significantly at a steady pace and in keeping them at levels that are sufficiently restrictive to ensure a timely return of inflation to our two per cent medium-term target. Accordingly, the Governing Council today decided to raise the three key ECB interest rates by 50 basis points and we expect to raise them further. In view of the underlying inflation pressures, we intend to raise interest rates by another 50 basis points at our next monetary policy meeting in March and we will then evaluate the subsequent path of our monetary policy." 

👉 In your opinion, why was the President of the ECB so committed to raising interest rates by a significant amount?
"""

# ╔═╡ b7708560-0101-447d-9a31-0aae4ede8310
md"""
!!! tip "Answer"

	The fundamental reason was that the level of inflation in the Euro Area was too high (at the time, it was close to 9%), and the ECB wanted to bring it down to 2%. In that press conference speech, we can find the justification for the ECB:

	>"Keeping interest rates at restrictive levels will over time reduce inflation by dampening demand and will also guard against the risk of a persistent upward shift in inflation expectations."

	The impact of higher interest rates on aggregate demand was already covered by us in the previous week $(\uparrow r \ \ \Rightarrow \ \downarrow D)$; while the second point mentioned by Lagarde ("upward shift in inflation expectations") will only be covered in week 7.
"""

# ╔═╡ 20363bb9-35ea-4f0d-968e-a4b83d317f8e
md"""
---
"""

# ╔═╡ 6537fb39-c597-41ca-8b65-2d2912b0234a
md"""
## Exercise 6. Increases in aggregate demand
"""

# ╔═╡ a1dc0363-8871-49d9-afc8-16a2660ae5c3
md"""
*Fom the textbook*

What would be the effect on the aggregate demand curve of a large increase in U.S. net exports, or in public expenditures? Would any of those increases affect the monetary policy curve? Explain why or why not.
"""

# ╔═╡ 4cc6e64e-4858-4f2a-b363-e7619c060bf8
md"""
!!! answer

	**1.** Any of those increases will increase aggregate demand by shifting the AD curve to the right. 

	**2.** If any of those increases lead to a **small rise** in inflation that can be accommodated with a small increase in the real interest rate, then none of them will shift the MP curve. 

	**3.** However, if any of those increases are so large that they will lead to a **large rise** in inflation, the central bank will have no other choice but promote a substantial increase in the real interest rate. In this case, there will be a shift of the MP curve to the right.

	"""

# ╔═╡ b99a4854-6671-4296-99b9-977af285812b
md"""
---
"""

# ╔═╡ e2bd0872-89de-4532-9be1-4b39c241133b
md"""
## Exercise 7. Monetary policy and employment
"""

# ╔═╡ 51b3a17c-2454-4cff-a1cc-a2f27d047f91
md"""

*From the textbook.*


Suppose U.S. aggregate output is still below potential by 2018, when a new Fed chair is appointed. Suppose his/her approach to monetary policy can be summarized by the following statement: “I care only about increasing employment; inflation has been at very low levels for quite some time; my priority is to ease monetary policy to promote employment.”

👉   **(a)** Would you expect the monetary policy curve to shift upward or downward?

👉   **(b)** What would be the effect on the aggregate demand curve?
"""

# ╔═╡ c7aea695-1c23-4abd-86a7-bcefce643898
md"""
!!! tip "Answer (a)"

	The sentence shows very clearly that the economy is not in a very good shape ("aggregate output is still below potential by 2018"), while an increase in employment is the crucial priority. So, the only tool available to the central bank is to reduce the real interest rate to stimulate aggregate demand, economic activity, and employment. Therefore, one should expect a shift of the MP curve to the left (or upwards). 

"""

# ╔═╡ 20b428c4-f680-45b0-af4d-f05fc5aea5bf
md"""
!!! tip "Answer (b)"

	A shift of the MP curve upwards will lead to an increase in aggregate demand, and the AD curve will shift upward as well (notice that in the case of the AD curve, this means a shift to the right). 

"""

# ╔═╡ a71621ac-f4f6-4b54-8486-b7bdaa8d29ef
md"""
---
"""

# ╔═╡ 747b89f4-fd33-4fc6-bd24-83b8860a5a5e
md"""
## Exercise 8. The twin goals of monetary policy
"""

# ╔═╡ b293a9cc-6c2e-4e8d-9445-9d377b83f676
md"""
*From the textbook "Macroeconomics", Fourth Edition, by Charles I. Jones, 2018, Pearson.*

Your day as chair of the Fed (I): Suppose you are appointed to chair the Federal Reserve. Your twin goals are to maintain low inflation and to stabilize economic activity — that is, to keep GDP at potential. Why are these appropriate goals for monetary policy? (Hint: What happens to inflation if the economy goes into a large boom? Or what happens to inflation in a deep recession?)

"""

# ╔═╡ b8c26c04-3448-4e47-8fb6-9ba6f13ab210
md"""
!!! answer
	**1.** These are appropriate goals because they reflect an almost idealistic situation. If GDP is at its potential level, no inflationary or disinflationary pressures exist, so inflation is stable and low. On the other hand, it also means that unemployment is at its natural level, which means no economic policy measure can reduce unemployment.  

	**2.** If we want the economy to be above potential GDP, we have to accept inflationary pressures to reduce unemployment below its natural rate. This is bad because the central bank can lose control of inflation. 

	**3.** If an economy becomes trapped with GDP too much below its potential level for a significant time, it may end up in a deflationary situation. This situation is the worst of all evils in macroeconomics (as we will see better in Week 10).
"""

# ╔═╡ 4ae438b1-0752-411f-ae55-52479f518c57
md"""
---
"""

# ╔═╡ d04e8abb-ae8e-4297-9734-533d9274274e
md"""
## Exercise 9. Large shocks and monetary policy
"""

# ╔═╡ 94b9b913-2a22-4960-992a-699f18954be2
md"""
*Adapted from the textbook "Macroeconomics", Fourth Edition, by Charles I. Jones, 2018, Pearson.*

Your day as chair of the Fed (II): With the goal of **stabilizing output**, explain how and why you would change the real interest rate in response to the following large shocks. Describe what happens in the short run using the AD-MP diagram (no need to use numerical simulations)

👉   **(a)** Consumers become extremely pessimistic about the state of the economy and future productivity growth.

"""

# ╔═╡ fa4ae288-aa26-4cc8-9edd-f0ed9bdf71e4
md"""
!!! tip "Answer (a)"

	Autonomous consumption will go down, and the AD curve will shift to the left. To stabilize GDP, the central bank will react by imposing a large reduction in real-interest rates, so the MP curve will move to the left until it forces the AD curve to return to its initial position.

"""

# ╔═╡ 3fceb728-e48e-41c5-8c26-ad158aa484d2
md"""
👉   **(b)** Improvements in information technology increase productivity and therefore increase the marginal product of capital (MPK).

"""

# ╔═╡ c6adfe92-4021-4b79-a480-5a5f490fd7e7
md"""
!!! tip "Answer (b)"

	An increase in the MPK will increase autonomous investment expenditures, and the AD curve will shift to the right. The central bank will have to increase the real interest rate, and the MP curve will change to the right until it forces the AD curve to return to its initial position. 

"""

# ╔═╡ 74385e49-c758-4a82-8c66-220c2f39902d
md"""

👉   **(c)** A booming economy in Europe leads to an unexpected increase in the demand for U.S. goods by European consumers.

"""

# ╔═╡ 35867d12-4044-4097-9dc9-55abdc8dcea8
md"""
!!! tip "Answer (c)"

	Net exports increase ... similar to the previous answer.

"""

# ╔═╡ 0b1c0b50-c54f-4603-8868-196990c92e0e
md"""
👉   **(d)** A housing bubble bursts, so that housing prices fall by 20% and new home sales drop sharply.
"""

# ╔═╡ 9f57850a-d036-42e2-815f-c6935826fbb2
md"""
!!! tip "Answer (d)"

	If a housing bubble bursts, investment expenditures drop significantly because the financial friction increases and autonomous investment decreases. Private consumption expenditures also go down (consumers' confidence is seriously affected). These two effects will produce a vast drop in aggregate demand: the AD curve drastically shifts to the left. 

	The central bank will have to reduce real-interest rates so much that they may need to reach negative values to fight a deep recession. If the central bank lowers the real interest rate by a lot (so the MP curve shifts to the left by a lot), it may force the AD curve to return to its initial position. Usually, as we will see in Week 10, that reduction in interest rates is not enough: the central bank will have to resort to "unconventional" monetary policy measures.
"""

# ╔═╡ 5e7d4fa1-84bb-4615-a3eb-60663baf4b5b
md"""
---
"""

# ╔═╡ 2c7c6904-52cd-459b-b459-daf6bdb4f91d
md"""
## Exercise 10. A very simple problem
"""

# ╔═╡ 40979b66-ab86-45ac-8102-64704d8bd613
md"""

*From the textbook.*

Suppose the monetary policy curve is given by $r = 1.5 + 0.75 \pi$, and the IS curve is given by $Y = 13 - r$.

(a) Find the expression for the aggregate demand curve.

(b) Calculate aggregate output when the inflation rate is at 2%, 3%, and 4%.

"""

# ╔═╡ 602a7f0f-6b1b-445c-8d3c-0887f858b1e0
md"""
!!! answers

    **(a)** From a numerical point of view, this is a very easy problem to solve. AD:  $Y = 11.5 - 0.75 \pi$.

	**(b)** This is extremely easy, so ... (if you want to use Julia, see Exercise 1)

	"""

# ╔═╡ 81c00071-63c2-48ff-96a9-b3ebcf8cc44f
md"""
---
"""

# ╔═╡ fd4a0888-c180-4f68-98e2-40061bc27354
md"""
## Auxiliary cells (do not delete)
"""

# ╔═╡ 18195c33-8d9e-431f-936b-b439a8b840a8
TableOfContents()

# ╔═╡ 4d1af171-01d5-4927-a046-814ccabbe315
md"""
##### Data files used in this notebook

- FFR.csv
- CPI.csv

These CSV files must be kept in the same folder as this notebook.
"""

# ╔═╡ dd2eecfa-edd9-4de7-b115-9fe7fc6832b8
md"### CSS code"

# ╔═╡ 5bd3a05c-17ea-4910-a90b-c6bdacb8b504
html"""
<style>
	@media screen {
		main {
			margin: 0 auto;
			max-width: 1550px;
    		padding-left: max(100px, 10%);
    		padding-right: max(380px, 10%); 
            # 383px to accomodate TableOfContents(aside=true)
		}
	}
</style>
"""

# ╔═╡ 0a80020e-ccba-4ed1-86a7-0efbb391b8a0
begin
      struct TwoColumns{L, R}
    left::L
    right::R
      end
      
      function Base.show(io, mime::MIME"text/html", tc::TwoColumns)
          write(io, """<div style="display: flex;"><div style="flex: 48%;margin-right:2%;">""")
          show(io, mime, tc.left)
          write(io, """</div><div style="flex: 48%;">""")
          show(io, mime, tc.right)
          write(io, """</div></div>""")
      end
end

# ╔═╡ 32c35ee9-0cf4-4707-9dc4-4f1c72b4b64d
md"""
### Exercises
"""

# ╔═╡ 31068d0a-0945-49a3-8c72-7a5ebb288db2
md"""
##### Exercise 3: supporting cells
"""

# ╔═╡ 1d1f906f-a672-4a0f-a35c-db1dfb0763fc
begin

	function fig_3b1()
		
		r3 = 1.5:0.01:7.0
	
		π3 = - (r̄3 ./ λ3) .+  r3 ./ λ3
	
		trace5_5 = scatter(; x = r3, y = π3, mode="lines" , line_color = "Brown", line_width = "3",
					name  = "MP")
	
		layout5_5 = Layout(;
					height = 450,
					title_text ="MP curve", 
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
                    xaxis_range = [1.5, 6.5],
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-1 ,9])

   		p5_5 = plot([trace5_5], layout5_5)
		
	end
	#fig_3b1()
end;

# ╔═╡ 89be032b-c88d-4de8-9f66-4acbdd3dec3d
begin
	function fig_3b2()
		
		Y3 = 12.0:0.01:14.6
		πdmax3 = (Ā3 / (λ3 * ϕ3)) - r̄3/λ3 		# The AD curve y-axis intercept 
	
		πd3 = πdmax3 .- ((1 ./(m3 .* ϕ3 .* λ3)) .* Y3)
	
		trace5_6 = scatter(; x = Y3, y = πd3, mode="lines" , line_color = "Blue", line_width = "3",
					name  = "AD")
	
	
		layout5_6 = Layout(;
					height = 450,
					title_text ="AD curve", 
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [12.6, 14.6],
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-1 ,9])

   		p5_6 = plot([trace5_6], layout5_6)
	end
	#fig_3b2()
		
end;

# ╔═╡ 4e65d2d8-c706-4a65-92ad-477e17ad39cb
begin
	p5_6A = [fig_3b1() fig_3b2()]
	relayout!(p5_6A, hovermode = "y", height = 480)
	p5_6A
end

# ╔═╡ 0d3c51a2-892b-4db1-a2af-fcddb75ef635
begin
	
	function fig_3c1()
		
		r3 = 1.5:0.01:7.0
		π3 = - (r̄3 ./ λ3) .+  r3 ./ λ3
	
		trace5_7 = scatter(; x = r3, y = π3, mode="lines" , line_color = "Brown", line_width = "3",
					name  = "MP")
	
		trace5_8 = scatter(; x = [3.0 , 4.0], y = [2.0 , 4.0], text =["1", "2"], 
					textposition = "top center", name ="Eq.", mode="markers+text", marker_size= "12",
					marker_color="Brown", textfont = attr(family="sans serif", size=16, color="black"))
	
	
		layout5_8 = Layout(;
					height = 450,
					title_text ="MP curve", 
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
                    xaxis_range = [1.5, 6.5],
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-1 ,9])

   		p5_8 = plot([trace5_7, trace5_8], layout5_8)
	end
	#fig_3c1()
end;

# ╔═╡ 1a055e0b-d23e-4d85-89bf-5813127e88ec
begin

	function fig_3c2()
		
		Y3 = 12.0:0.01:14.6

		πdmax3 = (Ā3 / (λ3 * ϕ3)) - r̄3/λ3 		# The AD curve y-axis intercept 

		πd3 = πdmax3 .- ((1 ./(m3 .* ϕ3 .* λ3)) .* Y3)
	
		trace5_9 = scatter(; x = Y3, y = πd3, mode="lines" , line_color = "Blue", line_width = "3",
					name  = "AD")
	
		trace5_10 = scatter(; x = [14.0 , 13.6], y = [2.0 , 4.0], text =["1", "2"], 
					textposition = "top center", name ="Eq.", mode="markers+text", marker_size= "12",
					marker_color="Blue", textfont = attr(family="sans serif", size=16, color="black"))
	
	
		layout5_10 = Layout(;
					height = 450,
					title_text ="AD curve", 
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [12.6, 14.6],
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-1 ,9])

   		p5_10 = plot([trace5_9, trace5_10], layout5_10)
	end

	#fig_3c2()
		
end;

# ╔═╡ bb50e179-3e60-4fab-9be4-3b56f254c710
begin
	p5_10A = [fig_3c1() fig_3c2()]
	relayout!(p5_10A, hovermode = "x", height = 480)
	p5_10A
end

# ╔═╡ 4a4d51cb-8626-4d97-91aa-c4ce37b0a210
begin
	
	function fig_3e1()
		
		r3 = 1.5:0.01:7.0
		π3 = - (r̄3 ./ λ3) .+  r3 ./ λ3
		r3_Δr̄3 = 1.5:0.01:7.0
		π3_Δr̄3 = - ((r̄3 .+ Δr̄3) ./ λ3) .+  r3 ./ λ3

		trace5_7 = scatter(; x = r3, y = π3, mode="lines" , line_color = "Brown", line_width = "3",
					name  = "MP")
		
		trace5_8 = scatter(; x = [3.0 , 4.0], y = [2.0 , 4.0], text =["1", "2"], 
					textposition = "top center", name ="Eq.", mode="markers+text", marker_size= "12",
					marker_color="Brown", textfont = attr(family="sans serif", size=16, color="black"))
	
		trace5_11 = scatter(; x = r3_Δr̄3, y = π3_Δr̄3, mode="lines" , line_color = "Purple", 
					line_width = "3", name  = "MP1")
	
		trace5_11A = scatter(; x = [4.0 , 5.0], y = [2.0 , 4.0], text =["1'", "2'"], 
					textposition = "top center", name ="Eq.", mode="markers+text", marker_size= "12",
					marker_color="Purple", textfont = attr(family="sans serif", size=16, color="black"))
	
		layout5_11 = Layout(;
					height = 450,
					title_text ="MP curve", 
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
                    xaxis_range = [1.5, 6.5],
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-1 ,9])

   		p5_11 = plot([trace5_11, trace5_7, trace5_11A, trace5_8], layout5_11)
		
	end
	
	#fig_3e1()
end;

# ╔═╡ f091ac64-be2c-4cc8-a7d3-34abde9fd5d4
begin
	function fig_3e2()
		
		Y3_Δr̄3 = 12.0:0.01:14.6

		πdmax3 = (Ā3 / (λ3 * ϕ3)) - r̄3/λ3 		# The AD curve y-axis intercept
	
		Y3 = 12.0:0.01:14.6

		πd3 = πdmax3 .- ((1 ./(m3 .* ϕ3 .* λ3)) .* Y3)

		πdmax3_Δr̄3 = (Ā3 / (λ3 * ϕ3)) - (r̄3 + Δr̄3) / λ3
		
		πd3_Δr̄3 = πdmax3_Δr̄3 .- ((1 ./(m3 .* ϕ3 .* λ3)) .* Y3_Δr̄3)

		trace5_9 = scatter(; x = Y3, y = πd3, mode="lines" , line_color = "Blue", line_width = "3",
					name  = "AD")

		trace5_10 = scatter(; x = [14.0 , 13.6], y = [2.0 , 4.0], text =["1", "2"], 
					textposition = "top center", name ="Eq.", mode="markers+text", marker_size= "12",
					marker_color="Blue", textfont = attr(family="sans serif", size=16, color="black"))
	
		trace5_12 = scatter(; x = Y3_Δr̄3 , y = πd3_Δr̄3, mode="lines" , line_color = "Violet", 
					line_width = "3", name  = "AD2")
	
		trace5_12A = scatter(; x = [13.6 , 13.2], y = [2.0 , 4.0], text =["1'", "2'"], 
					textposition = "top center", name ="Eq.", mode="markers+text", marker_size= "12",
					marker_color="Violet", textfont = attr(family="sans serif", size=16, color="black"))
		
		layout5_12 = Layout(;
					height = 450,
					title_text ="AD curve", 
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [12.6, 14.6],
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-1 , 9])

   		p5_12 = plot([trace5_12, trace5_9, trace5_12A, trace5_10], layout5_12)

	end

	#fig_3e2()
	
end;

# ╔═╡ 51818620-e43c-4db4-813b-ed5c4562b62c
begin
	p5_12A = [fig_3e1() fig_3e2()]
	relayout!(p5_12A, hovermode = "x", height = 480)
	p5_12A
end


# ╔═╡ 79d58d40-27ef-4a00-aac4-814501e6d9f8
md"""
##### Exercise 4: supporting cells
"""

# ╔═╡ 71f7c843-95a3-47d0-b5bb-800d375ba487
FFR = CSV.read("FFR.csv", DataFrame);

# ╔═╡ aa0a4d24-c142-4f5f-ab66-124bd71d8396
CPI = CSV.read("CPI.csv", DataFrame);

# ╔═╡ 8a83278b-95cf-497f-85ff-6b38c33b866f
let

    # Create the main layout with secondary y-axis and titles for all axes
    layout = Layout( height = 500, 
		hovermode = "x",
		title_text="The Fed Target Rate Range and the Fed Funds Rate",
		
		legend=attr( x=0.03, y=0.95, bgcolor="rgba(0,0,0,0)"),
    	#title="Plot with Two x-Axes and Two y-Axes",
		
        xaxis=attr(domain=[0, 0.98], 							# Primary x-axis with title
			title="Monthly observations", 
			showgrid=false),  
		
        #xaxis2=attr(anchor="y", 								# Secondary x-axis with title
		#	overlaying="x", 
		#	side="top", 
		#	title="Headline inflation in the 1970s (USA)"), 
		
        yaxis=attr(domain=[0, 0.98], 							# Primary y-axis with title
			title="Interest rates", 
			showgrid=true),  
       
		yaxis2=attr(overlaying="y", 
			zeroline = false,
			showgrid=false,# Secondary y-axis with title					
			side="right", 
			title="Inflation rate")  
    )

    # Define trace1 (primary y-axis)
    trace_cpi = scatter(; x=CPI.Months[1:157], y=CPI.HeadlineCPI[1:157], mode="lines", line_dash="dashdot", 
                          line_color="purple", line_width = 1.6, name="Inflation rate", yaxis="y2")
	
	trace_upper = scatter(; x=FFR.Weeks[1:680], y=FFR.UpperLimit[1:680], mode="lines", 
                          line_color="blue", name="Upper limit: target interest rate")

	trace_lower = scatter(; x=FFR.Weeks[1:680], y=FFR.LowerLimit[1:680], mode="lines", 
                          line_color="maroon", name="Lower limit: target interest rate")

	trace_range = scatter(; x=FFR.Weeks[1:680], y=FFR.LowerLimit[1:680], mode="lines", line_width = "0", 
                          line_color="maroon", name="Target range", 
                          fill="tonexty",
						  fillcolor="rgba(131, 90, 241, 0.8)" # 0.8 is the transparency
						  ) 

	trace_effr = scatter(; x=FFR.Weeks[1:680], y=FFR.FFR[1:680], mode="lines", 
                         line_color="orange", name="Federal Funds Rate")
	

    # Create the plot with the defined traces and layout
    fig = plot([trace_cpi, trace_upper, trace_range, trace_lower, trace_effr ], layout)

    # Show the plot
    fig
end

# ╔═╡ 00000000-0000-0000-0000-000000000001
PLUTO_PROJECT_TOML_CONTENTS = """
[deps]
CSV = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
DataFrames = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
Dates = "ade2ca70-3891-5945-98fb-dc099432e06a"
HypertextLiteral = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
PlutoPlotly = "8e989ff0-3d88-8e9f-f020-2b208a939ff0"
PlutoUI = "7f904dfe-b85e-4ff6-b463-dae2292396a8"

[compat]
CSV = "~0.10.14"
DataFrames = "~1.7.0"
HypertextLiteral = "~0.9.5"
PlutoPlotly = "~0.6.2"
PlutoUI = "~0.7.43"
"""

# ╔═╡ 00000000-0000-0000-0000-000000000002
PLUTO_MANIFEST_TOML_CONTENTS = """
# This file is machine-generated - editing it directly is not advised

julia_version = "1.11.3"
manifest_format = "2.0"
project_hash = "ff6488dc76db52f69497fb0f17b054e58185a9c6"

[[deps.AbstractPlutoDingetjes]]
deps = ["Pkg"]
git-tree-sha1 = "6e1d2a35f2f90a4bc7c2ed98079b2ba09c35b83a"
uuid = "6e696c72-6542-2067-7265-42206c756150"
version = "1.3.2"

[[deps.ArgTools]]
uuid = "0dad84c5-d112-42e6-8d28-ef12dabb789f"
version = "1.1.2"

[[deps.Artifacts]]
uuid = "56f22d72-fd6d-98f1-02f0-08ddc0907c33"
version = "1.11.0"

[[deps.Base64]]
uuid = "2a0f44e3-6c83-55bd-87e4-b1978d98bd5f"
version = "1.11.0"

[[deps.CSV]]
deps = ["CodecZlib", "Dates", "FilePathsBase", "InlineStrings", "Mmap", "Parsers", "PooledArrays", "PrecompileTools", "SentinelArrays", "Tables", "Unicode", "WeakRefStrings", "WorkerUtilities"]
git-tree-sha1 = "deddd8725e5e1cc49ee205a1964256043720a6c3"
uuid = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
version = "0.10.15"

[[deps.CodecZlib]]
deps = ["TranscodingStreams", "Zlib_jll"]
git-tree-sha1 = "962834c22b66e32aa10f7611c08c8ca4e20749a9"
uuid = "944b1d66-785c-5afd-91f1-9de20f533193"
version = "0.7.8"

[[deps.ColorSchemes]]
deps = ["ColorTypes", "ColorVectorSpace", "Colors", "FixedPointNumbers", "PrecompileTools", "Random"]
git-tree-sha1 = "403f2d8e209681fcbd9468a8514efff3ea08452e"
uuid = "35d6a980-a343-548e-a6ea-1d62b119f2f4"
version = "3.29.0"

[[deps.ColorTypes]]
deps = ["FixedPointNumbers", "Random"]
git-tree-sha1 = "b10d0b65641d57b8b4d5e234446582de5047050d"
uuid = "3da002f7-5984-5a60-b8a6-cbb66c0b333f"
version = "0.11.5"

[[deps.ColorVectorSpace]]
deps = ["ColorTypes", "FixedPointNumbers", "LinearAlgebra", "Requires", "Statistics", "TensorCore"]
git-tree-sha1 = "a1f44953f2382ebb937d60dafbe2deea4bd23249"
uuid = "c3611d14-8923-5661-9e6a-0046d554d3a4"
version = "0.10.0"

    [deps.ColorVectorSpace.extensions]
    SpecialFunctionsExt = "SpecialFunctions"

    [deps.ColorVectorSpace.weakdeps]
    SpecialFunctions = "276daf66-3868-5448-9aa4-cd146d93841b"

[[deps.Colors]]
deps = ["ColorTypes", "FixedPointNumbers", "Reexport"]
git-tree-sha1 = "362a287c3aa50601b0bc359053d5c2468f0e7ce0"
uuid = "5ae59095-9a9b-59fe-a467-6f913c188581"
version = "0.12.11"

[[deps.Compat]]
deps = ["TOML", "UUIDs"]
git-tree-sha1 = "8ae8d32e09f0dcf42a36b90d4e17f5dd2e4c4215"
uuid = "34da2185-b29b-5c13-b0c7-acf172513d20"
version = "4.16.0"
weakdeps = ["Dates", "LinearAlgebra"]

    [deps.Compat.extensions]
    CompatLinearAlgebraExt = "LinearAlgebra"

[[deps.CompilerSupportLibraries_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "e66e0078-7015-5450-92f7-15fbd957f2ae"
version = "1.1.1+0"

[[deps.Crayons]]
git-tree-sha1 = "249fe38abf76d48563e2f4556bebd215aa317e15"
uuid = "a8cc5b0e-0ffa-5ad4-8c14-923d3ee1735f"
version = "4.1.1"

[[deps.DataAPI]]
git-tree-sha1 = "abe83f3a2f1b857aac70ef8b269080af17764bbe"
uuid = "9a962f9c-6df0-11e9-0e5d-c546b8b5ee8a"
version = "1.16.0"

[[deps.DataFrames]]
deps = ["Compat", "DataAPI", "DataStructures", "Future", "InlineStrings", "InvertedIndices", "IteratorInterfaceExtensions", "LinearAlgebra", "Markdown", "Missings", "PooledArrays", "PrecompileTools", "PrettyTables", "Printf", "Random", "Reexport", "SentinelArrays", "SortingAlgorithms", "Statistics", "TableTraits", "Tables", "Unicode"]
git-tree-sha1 = "fb61b4812c49343d7ef0b533ba982c46021938a6"
uuid = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
version = "1.7.0"

[[deps.DataStructures]]
deps = ["Compat", "InteractiveUtils", "OrderedCollections"]
git-tree-sha1 = "1d0a14036acb104d9e89698bd408f63ab58cdc82"
uuid = "864edb3b-99cc-5e75-8d2d-829cb0a9cfe8"
version = "0.18.20"

[[deps.DataValueInterfaces]]
git-tree-sha1 = "bfc1187b79289637fa0ef6d4436ebdfe6905cbd6"
uuid = "e2d170a0-9d28-54be-80f0-106bbe20a464"
version = "1.0.0"

[[deps.Dates]]
deps = ["Printf"]
uuid = "ade2ca70-3891-5945-98fb-dc099432e06a"
version = "1.11.0"

[[deps.DelimitedFiles]]
deps = ["Mmap"]
git-tree-sha1 = "9e2f36d3c96a820c678f2f1f1782582fcf685bae"
uuid = "8bb1440f-4735-579b-a4ab-409b98df4dab"
version = "1.9.1"

[[deps.DocStringExtensions]]
deps = ["LibGit2"]
git-tree-sha1 = "2fb1e02f2b635d0845df5d7c167fec4dd739b00d"
uuid = "ffbed154-4ef7-542d-bbb7-c09d3a79fcae"
version = "0.9.3"

[[deps.Downloads]]
deps = ["ArgTools", "FileWatching", "LibCURL", "NetworkOptions"]
uuid = "f43a241f-c20a-4ad4-852c-f6b1247861c6"
version = "1.6.0"

[[deps.FilePathsBase]]
deps = ["Compat", "Dates"]
git-tree-sha1 = "2ec417fc319faa2d768621085cc1feebbdee686b"
uuid = "48062228-2e41-5def-b9a4-89aafe57970f"
version = "0.9.23"
weakdeps = ["Mmap", "Test"]

    [deps.FilePathsBase.extensions]
    FilePathsBaseMmapExt = "Mmap"
    FilePathsBaseTestExt = "Test"

[[deps.FileWatching]]
uuid = "7b1f6079-737a-58dc-b8bc-7a2ca5c1b5ee"
version = "1.11.0"

[[deps.FixedPointNumbers]]
deps = ["Statistics"]
git-tree-sha1 = "05882d6995ae5c12bb5f36dd2ed3f61c98cbb172"
uuid = "53c48c17-4a7d-5ca2-90c5-79b7896eea93"
version = "0.8.5"

[[deps.Future]]
deps = ["Random"]
uuid = "9fa8497b-333b-5362-9e8d-4d0656e87820"
version = "1.11.0"

[[deps.HashArrayMappedTries]]
git-tree-sha1 = "2eaa69a7cab70a52b9687c8bf950a5a93ec895ae"
uuid = "076d061b-32b6-4027-95e0-9a2c6f6d7e74"
version = "0.2.0"

[[deps.Hyperscript]]
deps = ["Test"]
git-tree-sha1 = "179267cfa5e712760cd43dcae385d7ea90cc25a4"
uuid = "47d2ed2b-36de-50cf-bf87-49c2cf4b8b91"
version = "0.0.5"

[[deps.HypertextLiteral]]
deps = ["Tricks"]
git-tree-sha1 = "7134810b1afce04bbc1045ca1985fbe81ce17653"
uuid = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
version = "0.9.5"

[[deps.IOCapture]]
deps = ["Logging", "Random"]
git-tree-sha1 = "b6d6bfdd7ce25b0f9b2f6b3dd56b2673a66c8770"
uuid = "b5f81e59-6552-4d32-b1f0-c071b021bf89"
version = "0.2.5"

[[deps.InlineStrings]]
git-tree-sha1 = "45521d31238e87ee9f9732561bfee12d4eebd52d"
uuid = "842dd82b-1e85-43dc-bf29-5d0ee9dffc48"
version = "1.4.2"

    [deps.InlineStrings.extensions]
    ArrowTypesExt = "ArrowTypes"
    ParsersExt = "Parsers"

    [deps.InlineStrings.weakdeps]
    ArrowTypes = "31f734f8-188a-4ce0-8406-c8a06bd891cd"
    Parsers = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"

[[deps.InteractiveUtils]]
deps = ["Markdown"]
uuid = "b77e0a4c-d291-57a0-90e8-8db25a27a240"
version = "1.11.0"

[[deps.InvertedIndices]]
git-tree-sha1 = "6da3c4316095de0f5ee2ebd875df8721e7e0bdbe"
uuid = "41ab1584-1d38-5bbf-9106-f11c6c58b48f"
version = "1.3.1"

[[deps.IteratorInterfaceExtensions]]
git-tree-sha1 = "a3f24677c21f5bbe9d2a714f95dcd58337fb2856"
uuid = "82899510-4779-5014-852e-03e436cf321d"
version = "1.0.0"

[[deps.JSON]]
deps = ["Dates", "Mmap", "Parsers", "Unicode"]
git-tree-sha1 = "31e996f0a15c7b280ba9f76636b3ff9e2ae58c9a"
uuid = "682c06a0-de6a-54ab-a142-c8b1cf79cde6"
version = "0.21.4"

[[deps.LaTeXStrings]]
git-tree-sha1 = "dda21b8cbd6a6c40d9d02a73230f9d70fed6918c"
uuid = "b964fa9f-0449-5b57-a5c2-d3ea65f4040f"
version = "1.4.0"

[[deps.LibCURL]]
deps = ["LibCURL_jll", "MozillaCACerts_jll"]
uuid = "b27032c2-a3e7-50c8-80cd-2d36dbcbfd21"
version = "0.6.4"

[[deps.LibCURL_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll", "Zlib_jll", "nghttp2_jll"]
uuid = "deac9b47-8bc7-5906-a0fe-35ac56dc84c0"
version = "8.6.0+0"

[[deps.LibGit2]]
deps = ["Base64", "LibGit2_jll", "NetworkOptions", "Printf", "SHA"]
uuid = "76f85450-5226-5b5a-8eaa-529ad045b433"
version = "1.11.0"

[[deps.LibGit2_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll"]
uuid = "e37daf67-58a4-590a-8e99-b0245dd2ffc5"
version = "1.7.2+0"

[[deps.LibSSH2_jll]]
deps = ["Artifacts", "Libdl", "MbedTLS_jll"]
uuid = "29816b5a-b9ab-546f-933c-edad1886dfa8"
version = "1.11.0+1"

[[deps.Libdl]]
uuid = "8f399da3-3557-5675-b5ff-fb832c97cbdb"
version = "1.11.0"

[[deps.LinearAlgebra]]
deps = ["Libdl", "OpenBLAS_jll", "libblastrampoline_jll"]
uuid = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"
version = "1.11.0"

[[deps.Logging]]
uuid = "56ddb016-857b-54e1-b83d-db4d58db5568"
version = "1.11.0"

[[deps.MIMEs]]
git-tree-sha1 = "1833212fd6f580c20d4291da9c1b4e8a655b128e"
uuid = "6c6e2e6c-3030-632d-7369-2d6c69616d65"
version = "1.0.0"

[[deps.Markdown]]
deps = ["Base64"]
uuid = "d6f4376e-aef5-505a-96c1-9c027394607a"
version = "1.11.0"

[[deps.MbedTLS_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "c8ffd9c3-330d-5841-b78e-0817d7145fa1"
version = "2.28.6+0"

[[deps.Missings]]
deps = ["DataAPI"]
git-tree-sha1 = "ec4f7fbeab05d7747bdf98eb74d130a2a2ed298d"
uuid = "e1d29d7a-bbdc-5cf2-9ac0-f12de2c33e28"
version = "1.2.0"

[[deps.Mmap]]
uuid = "a63ad114-7e13-5084-954f-fe012c677804"
version = "1.11.0"

[[deps.MozillaCACerts_jll]]
uuid = "14a3606d-f60d-562e-9121-12d972cd8159"
version = "2023.12.12"

[[deps.NetworkOptions]]
uuid = "ca575930-c2e3-43a9-ace4-1e988b2c1908"
version = "1.2.0"

[[deps.OpenBLAS_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "Libdl"]
uuid = "4536629a-c528-5b80-bd46-f80d51c5b363"
version = "0.3.27+1"

[[deps.OrderedCollections]]
git-tree-sha1 = "cc4054e898b852042d7b503313f7ad03de99c3dd"
uuid = "bac558e1-5e72-5ebc-8fee-abe8a469f55d"
version = "1.8.0"

[[deps.Parameters]]
deps = ["OrderedCollections", "UnPack"]
git-tree-sha1 = "34c0e9ad262e5f7fc75b10a9952ca7692cfc5fbe"
uuid = "d96e819e-fc66-5662-9728-84c9c7592b0a"
version = "0.12.3"

[[deps.Parsers]]
deps = ["Dates", "PrecompileTools", "UUIDs"]
git-tree-sha1 = "8489905bcdbcfac64d1daa51ca07c0d8f0283821"
uuid = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"
version = "2.8.1"

[[deps.Pkg]]
deps = ["Artifacts", "Dates", "Downloads", "FileWatching", "LibGit2", "Libdl", "Logging", "Markdown", "Printf", "Random", "SHA", "TOML", "Tar", "UUIDs", "p7zip_jll"]
uuid = "44cfe95a-1eb2-52ea-b672-e2afdf69b78f"
version = "1.11.0"
weakdeps = ["REPL"]

    [deps.Pkg.extensions]
    REPLExt = "REPL"

[[deps.PlotlyBase]]
deps = ["ColorSchemes", "Dates", "DelimitedFiles", "DocStringExtensions", "JSON", "LaTeXStrings", "Logging", "Parameters", "Pkg", "REPL", "Requires", "Statistics", "UUIDs"]
git-tree-sha1 = "56baf69781fc5e61607c3e46227ab17f7040ffa2"
uuid = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
version = "0.8.19"

[[deps.PlutoPlotly]]
deps = ["AbstractPlutoDingetjes", "Artifacts", "ColorSchemes", "Colors", "Dates", "Downloads", "HypertextLiteral", "InteractiveUtils", "LaTeXStrings", "Markdown", "Pkg", "PlotlyBase", "PrecompileTools", "Reexport", "ScopedValues", "Scratch", "TOML"]
git-tree-sha1 = "9ebe25fc4703d4112cc418834d5e4c9a4b29087d"
uuid = "8e989ff0-3d88-8e9f-f020-2b208a939ff0"
version = "0.6.2"

    [deps.PlutoPlotly.extensions]
    PlotlyKaleidoExt = "PlotlyKaleido"
    UnitfulExt = "Unitful"

    [deps.PlutoPlotly.weakdeps]
    PlotlyKaleido = "f2990250-8cf9-495f-b13a-cce12b45703c"
    Unitful = "1986cc42-f94f-5a68-af5c-568840ba703d"

[[deps.PlutoUI]]
deps = ["AbstractPlutoDingetjes", "Base64", "ColorTypes", "Dates", "FixedPointNumbers", "Hyperscript", "HypertextLiteral", "IOCapture", "InteractiveUtils", "JSON", "Logging", "MIMEs", "Markdown", "Random", "Reexport", "URIs", "UUIDs"]
git-tree-sha1 = "7e71a55b87222942f0f9337be62e26b1f103d3e4"
uuid = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
version = "0.7.61"

[[deps.PooledArrays]]
deps = ["DataAPI", "Future"]
git-tree-sha1 = "36d8b4b899628fb92c2749eb488d884a926614d3"
uuid = "2dfb63ee-cc39-5dd5-95bd-886bf059d720"
version = "1.4.3"

[[deps.PrecompileTools]]
deps = ["Preferences"]
git-tree-sha1 = "5aa36f7049a63a1528fe8f7c3f2113413ffd4e1f"
uuid = "aea7be01-6a6a-4083-8856-8a6e6704d82a"
version = "1.2.1"

[[deps.Preferences]]
deps = ["TOML"]
git-tree-sha1 = "9306f6085165d270f7e3db02af26a400d580f5c6"
uuid = "21216c6a-2e73-6563-6e65-726566657250"
version = "1.4.3"

[[deps.PrettyTables]]
deps = ["Crayons", "LaTeXStrings", "Markdown", "PrecompileTools", "Printf", "Reexport", "StringManipulation", "Tables"]
git-tree-sha1 = "1101cd475833706e4d0e7b122218257178f48f34"
uuid = "08abe8d2-0d0c-5749-adfa-8a2ac140af0d"
version = "2.4.0"

[[deps.Printf]]
deps = ["Unicode"]
uuid = "de0858da-6303-5e67-8744-51eddeeeb8d7"
version = "1.11.0"

[[deps.REPL]]
deps = ["InteractiveUtils", "Markdown", "Sockets", "StyledStrings", "Unicode"]
uuid = "3fa0cd96-eef1-5676-8a61-b3b8758bbffb"
version = "1.11.0"

[[deps.Random]]
deps = ["SHA"]
uuid = "9a3f8284-a2c9-5f02-9a11-845980a1fd5c"
version = "1.11.0"

[[deps.Reexport]]
git-tree-sha1 = "45e428421666073eab6f2da5c9d310d99bb12f9b"
uuid = "189a3867-3050-52da-a836-e630ba90ab69"
version = "1.2.2"

[[deps.Requires]]
deps = ["UUIDs"]
git-tree-sha1 = "838a3a4188e2ded87a4f9f184b4b0d78a1e91cb7"
uuid = "ae029012-a4dd-5104-9daa-d747884805df"
version = "1.3.0"

[[deps.SHA]]
uuid = "ea8e919c-243c-51af-8825-aaa63cd721ce"
version = "0.7.0"

[[deps.ScopedValues]]
deps = ["HashArrayMappedTries", "Logging"]
git-tree-sha1 = "1147f140b4c8ddab224c94efa9569fc23d63ab44"
uuid = "7e506255-f358-4e82-b7e4-beb19740aa63"
version = "1.3.0"

[[deps.Scratch]]
deps = ["Dates"]
git-tree-sha1 = "3bac05bc7e74a75fd9cba4295cde4045d9fe2386"
uuid = "6c6a2e73-6563-6170-7368-637461726353"
version = "1.2.1"

[[deps.SentinelArrays]]
deps = ["Dates", "Random"]
git-tree-sha1 = "712fb0231ee6f9120e005ccd56297abbc053e7e0"
uuid = "91c51154-3ec4-41a3-a24f-3f23e20d615c"
version = "1.4.8"

[[deps.Serialization]]
uuid = "9e88b42a-f829-5b0c-bbe9-9e923198166b"
version = "1.11.0"

[[deps.Sockets]]
uuid = "6462fe0b-24de-5631-8697-dd941f90decc"
version = "1.11.0"

[[deps.SortingAlgorithms]]
deps = ["DataStructures"]
git-tree-sha1 = "66e0a8e672a0bdfca2c3f5937efb8538b9ddc085"
uuid = "a2af1166-a08f-5f64-846c-94a0d3cef48c"
version = "1.2.1"

[[deps.Statistics]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "ae3bb1eb3bba077cd276bc5cfc337cc65c3075c0"
uuid = "10745b16-79ce-11e8-11f9-7d13ad32a3b2"
version = "1.11.1"

    [deps.Statistics.extensions]
    SparseArraysExt = ["SparseArrays"]

    [deps.Statistics.weakdeps]
    SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"

[[deps.StringManipulation]]
deps = ["PrecompileTools"]
git-tree-sha1 = "725421ae8e530ec29bcbdddbe91ff8053421d023"
uuid = "892a3eda-7b42-436c-8928-eab12a02cf0e"
version = "0.4.1"

[[deps.StyledStrings]]
uuid = "f489334b-da3d-4c2e-b8f0-e476e12c162b"
version = "1.11.0"

[[deps.TOML]]
deps = ["Dates"]
uuid = "fa267f1f-6049-4f14-aa54-33bafae1ed76"
version = "1.0.3"

[[deps.TableTraits]]
deps = ["IteratorInterfaceExtensions"]
git-tree-sha1 = "c06b2f539df1c6efa794486abfb6ed2022561a39"
uuid = "3783bdb8-4a98-5b6b-af9a-565f29a5fe9c"
version = "1.0.1"

[[deps.Tables]]
deps = ["DataAPI", "DataValueInterfaces", "IteratorInterfaceExtensions", "OrderedCollections", "TableTraits"]
git-tree-sha1 = "598cd7c1f68d1e205689b1c2fe65a9f85846f297"
uuid = "bd369af6-aec1-5ad0-b16a-f7cc5008161c"
version = "1.12.0"

[[deps.Tar]]
deps = ["ArgTools", "SHA"]
uuid = "a4e569a6-e804-4fa4-b0f3-eef7a1d5b13e"
version = "1.10.0"

[[deps.TensorCore]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "1feb45f88d133a655e001435632f019a9a1bcdb6"
uuid = "62fd8b95-f654-4bbd-a8a5-9c27f68ccd50"
version = "0.1.1"

[[deps.Test]]
deps = ["InteractiveUtils", "Logging", "Random", "Serialization"]
uuid = "8dfed614-e22c-5e08-85e1-65c5234f0b40"
version = "1.11.0"

[[deps.TranscodingStreams]]
git-tree-sha1 = "0c45878dcfdcfa8480052b6ab162cdd138781742"
uuid = "3bb67fe8-82b1-5028-8e26-92a6c54297fa"
version = "0.11.3"

[[deps.Tricks]]
git-tree-sha1 = "6cae795a5a9313bbb4f60683f7263318fc7d1505"
uuid = "410a4b4d-49e4-4fbc-ab6d-cb71b17b3775"
version = "0.1.10"

[[deps.URIs]]
git-tree-sha1 = "67db6cc7b3821e19ebe75791a9dd19c9b1188f2b"
uuid = "5c2747f8-b7ea-4ff2-ba2e-563bfd36b1d4"
version = "1.5.1"

[[deps.UUIDs]]
deps = ["Random", "SHA"]
uuid = "cf7118a7-6976-5b1a-9a39-7adc72f591a4"
version = "1.11.0"

[[deps.UnPack]]
git-tree-sha1 = "387c1f73762231e86e0c9c5443ce3b4a0a9a0c2b"
uuid = "3a884ed6-31ef-47d7-9d2a-63182c4928ed"
version = "1.0.2"

[[deps.Unicode]]
uuid = "4ec0a83e-493e-50e2-b9ac-8f72acf5a8f5"
version = "1.11.0"

[[deps.WeakRefStrings]]
deps = ["DataAPI", "InlineStrings", "Parsers"]
git-tree-sha1 = "b1be2855ed9ed8eac54e5caff2afcdb442d52c23"
uuid = "ea10d353-3f73-51f8-a26c-33c1cb351aa5"
version = "1.4.2"

[[deps.WorkerUtilities]]
git-tree-sha1 = "cd1659ba0d57b71a464a29e64dbc67cfe83d54e7"
uuid = "76eceee3-57b5-4d4a-8e66-0e911cebbf60"
version = "1.6.1"

[[deps.Zlib_jll]]
deps = ["Libdl"]
uuid = "83775a58-1f1d-513f-b197-d71354ab007a"
version = "1.2.13+1"

[[deps.libblastrampoline_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850b90-86db-534c-a0d3-1478176c7d93"
version = "5.11.0+0"

[[deps.nghttp2_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850ede-7688-5339-a07c-302acd2aaf8d"
version = "1.59.0+0"

[[deps.p7zip_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "3f19e933-33d8-53b3-aaab-bd5110c3b7a0"
version = "17.4.0+2"
"""

# ╔═╡ Cell order:
# ╟─f9dd4fc1-c759-4d80-b560-4ede0a84f6e9
# ╟─15112ba0-cddf-11eb-07a3-2bcd9257c8d0
# ╟─3cdf6437-0705-410c-8b0b-e8fc657897ed
# ╟─49a435e3-e710-4d01-84f5-396b151316e3
# ╟─409f9114-3fe1-4abe-8beb-ab279e9031b2
# ╠═feb39810-13bf-4383-8184-9338111248cf
# ╟─ced63ea2-60c8-4913-a5d4-9e1b5ff47223
# ╟─6571612f-00ad-4179-bb93-a48cc9804352
# ╟─dac7fb80-10f7-4806-af0c-088637b79b69
# ╟─164f08a1-63b2-42e5-9811-a0431b7a667c
# ╟─dd38b7eb-925e-4691-8b51-b77acce6c48c
# ╟─370b96a7-a5dd-45c4-a46f-1d13a4f87663
# ╟─96d63fec-da09-4c16-8019-10a6b63d3f73
# ╟─4471e3b1-fa13-4ae7-a78b-458e4d685933
# ╠═f1acdec8-d55b-4b12-9b67-84c47be9378e
# ╟─3f23006c-9918-4883-a1c2-f982862f2cf3
# ╟─ce89db42-eabe-4d30-8d0a-4b06ad04145a
# ╟─d38d5d7e-ef45-40e7-90c0-441fa4d30a24
# ╟─0120645b-0386-4fdd-b7fd-ace3f58c2d4d
# ╟─f1a259ac-e3c3-457a-9111-5eab394f452f
# ╟─1b35a949-7c83-4d64-aa69-90b42c5dfbfb
# ╟─5235a517-8947-4d57-a436-c48eb3de87c6
# ╟─aa6e1a71-1cc4-4ddc-b080-11de86462656
# ╟─6bf1aae8-5d3a-4aa2-b01c-d633602f3c55
# ╟─0fd242c3-a99f-41b3-a5ed-1c92f6d3b600
# ╟─4c2622b9-191f-4e38-b5f4-c0eece8cb7af
# ╟─559be550-e0b0-4cd4-bd16-f7757bb190cb
# ╟─39562a1b-7a97-4ccd-b57c-9fb4bb15ba65
# ╟─85981e5d-1519-4dca-8739-4023e58a0176
# ╟─7d5db723-241f-4504-b7d7-8c1e50a3b5a8
# ╠═2995b122-9938-4027-8c1f-89967ddf5f75
# ╟─72b279a0-9405-4a39-b715-4a7352cc5b45
# ╟─022623ff-7979-4690-9c1a-0c8977c1d976
# ╟─0c8a41dd-b6c6-47ed-b4dc-2c81b6638044
# ╟─3556cde6-e9b0-4dab-a8ae-dbc24f524b22
# ╟─ebb43969-4b22-4e8e-8694-6b47a8726b86
# ╟─b20800ee-7d04-4e15-9aa0-d86aca961461
# ╟─4e65d2d8-c706-4a65-92ad-477e17ad39cb
# ╟─280f3cc5-0a2b-4cd3-bcfb-cba536877019
# ╟─91a1906c-f969-4265-911c-2dfab3bf35bf
# ╟─bb50e179-3e60-4fab-9be4-3b56f254c710
# ╟─5bbebe42-69cd-474a-ad1a-8599fed108be
# ╟─4cd62077-945d-4b33-af50-739612c29410
# ╟─fd292c9b-ed3e-4f91-aea6-4142e429163a
# ╟─5c2e6ae3-cfda-4653-8e47-b6dc018129b5
# ╟─1fb6c731-ff80-41fd-b866-0db9ad4ec361
# ╟─51818620-e43c-4db4-813b-ed5c4562b62c
# ╟─5fe68e9d-3ff2-495e-b844-649e273ce758
# ╟─0f86d6fa-bdd4-4018-b3af-39e0bb1288f7
# ╟─113c8a60-335b-4b3b-bffa-9e7e9de7aa1b
# ╟─b22cdf3b-4806-4ab9-8b4a-a4112bb9de26
# ╟─8a83278b-95cf-497f-85ff-6b38c33b866f
# ╟─b91fc2c4-afa9-4ed5-bf33-67ac2aadd7b6
# ╟─8596ced0-f0fa-46b4-be9a-30a16798f203
# ╟─ac06af9d-9cf5-4229-9cd3-dfdb2492c18e
# ╟─113036a0-df28-4c86-aad8-df89b4b3129f
# ╟─8c1fa8b9-f490-4ac5-83cb-75317a6d1f37
# ╟─92296571-e28b-4fbc-9529-551a80e3aefc
# ╟─facf71b4-61fc-42eb-8cbc-44f120a5fb94
# ╟─eff0090d-8174-4f9f-a454-b8377b6f331c
# ╟─b8685f1b-5f5f-4f9f-9b98-32521ca26d24
# ╟─96c81523-b9b1-46a5-9880-a4152e097a58
# ╟─6cdba781-6a44-496f-869a-f6c83208b49b
# ╟─a5de4a7b-5768-49d7-b273-97b929f38d95
# ╟─b7708560-0101-447d-9a31-0aae4ede8310
# ╟─20363bb9-35ea-4f0d-968e-a4b83d317f8e
# ╟─6537fb39-c597-41ca-8b65-2d2912b0234a
# ╟─a1dc0363-8871-49d9-afc8-16a2660ae5c3
# ╟─4cc6e64e-4858-4f2a-b363-e7619c060bf8
# ╟─b99a4854-6671-4296-99b9-977af285812b
# ╟─e2bd0872-89de-4532-9be1-4b39c241133b
# ╟─51b3a17c-2454-4cff-a1cc-a2f27d047f91
# ╟─c7aea695-1c23-4abd-86a7-bcefce643898
# ╟─20b428c4-f680-45b0-af4d-f05fc5aea5bf
# ╟─a71621ac-f4f6-4b54-8486-b7bdaa8d29ef
# ╟─747b89f4-fd33-4fc6-bd24-83b8860a5a5e
# ╟─b293a9cc-6c2e-4e8d-9445-9d377b83f676
# ╟─b8c26c04-3448-4e47-8fb6-9ba6f13ab210
# ╟─4ae438b1-0752-411f-ae55-52479f518c57
# ╟─d04e8abb-ae8e-4297-9734-533d9274274e
# ╟─94b9b913-2a22-4960-992a-699f18954be2
# ╟─fa4ae288-aa26-4cc8-9edd-f0ed9bdf71e4
# ╟─3fceb728-e48e-41c5-8c26-ad158aa484d2
# ╟─c6adfe92-4021-4b79-a480-5a5f490fd7e7
# ╟─74385e49-c758-4a82-8c66-220c2f39902d
# ╟─35867d12-4044-4097-9dc9-55abdc8dcea8
# ╟─0b1c0b50-c54f-4603-8868-196990c92e0e
# ╟─9f57850a-d036-42e2-815f-c6935826fbb2
# ╟─5e7d4fa1-84bb-4615-a3eb-60663baf4b5b
# ╟─2c7c6904-52cd-459b-b459-daf6bdb4f91d
# ╟─40979b66-ab86-45ac-8102-64704d8bd613
# ╟─602a7f0f-6b1b-445c-8d3c-0887f858b1e0
# ╟─81c00071-63c2-48ff-96a9-b3ebcf8cc44f
# ╟─fd4a0888-c180-4f68-98e2-40061bc27354
# ╟─18195c33-8d9e-431f-936b-b439a8b840a8
# ╟─4d1af171-01d5-4927-a046-814ccabbe315
# ╟─dd2eecfa-edd9-4de7-b115-9fe7fc6832b8
# ╟─5bd3a05c-17ea-4910-a90b-c6bdacb8b504
# ╟─0a80020e-ccba-4ed1-86a7-0efbb391b8a0
# ╟─32c35ee9-0cf4-4707-9dc4-4f1c72b4b64d
# ╟─31068d0a-0945-49a3-8c72-7a5ebb288db2
# ╟─1d1f906f-a672-4a0f-a35c-db1dfb0763fc
# ╟─89be032b-c88d-4de8-9f66-4acbdd3dec3d
# ╟─0d3c51a2-892b-4db1-a2af-fcddb75ef635
# ╟─1a055e0b-d23e-4d85-89bf-5813127e88ec
# ╟─4a4d51cb-8626-4d97-91aa-c4ce37b0a210
# ╟─f091ac64-be2c-4cc8-a7d3-34abde9fd5d4
# ╟─79d58d40-27ef-4a00-aac4-814501e6d9f8
# ╟─71f7c843-95a3-47d0-b5bb-800d375ba487
# ╟─aa0a4d24-c142-4f5f-ab66-124bd71d8396
# ╟─00000000-0000-0000-0000-000000000001
# ╟─00000000-0000-0000-0000-000000000002
